Name:           cal10n
Version:        0.8.1
Release:        %mkrel 8
Group:          Development/Java
Summary:        Compiler assisted localization library (CAL10N)
License:        MIT
URL:            https://cal10n.qos.ch/
# ./generate-tarball.sh
Source0:        %{name}-%{version}.tar.gz
# Remove bundled binaries which cannot be easily verified for licensing
Source1:        generate-tarball.sh
BuildArch:      noarch

BuildRequires:  maven-local
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.maven:maven-artifact)
BuildRequires:  mvn(org.apache.maven:maven-artifact-manager)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.apache.maven.plugins:maven-source-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)

%description
Compiler Assisted Localization, abbreviated as CAL10N (pronounced as "calion")
is a java library for writing localized (internationalized) messages.
Features:
    * java compiler verifies message keys used in source code
    * tooling to detect errors in message keys
    * native2ascii tool made superfluous, as you can directly encode bundles
      in the most convenient charset, per locale.
    * good performance (300 nanoseconds per key look-up)
    * automatic reloading of resource bundles upon change


%package javadoc
Summary:        API documentation for %{name}

%description javadoc
%{summary}.

%package -n maven-%{name}-plugin
Summary:        CAL10N maven plugin

%description -n maven-%{name}-plugin
Maven plugin verifying that the codes defined in
an enum type match those in the corresponding resource bundles. 

%prep
%setup -q -n %{name}-v_%{version}

find . -name \*.jar -delete

%pom_xpath_remove pom:extensions
%pom_add_dep org.apache.maven:maven-artifact maven-%{name}-plugin
%pom_disable_module %{name}-site
%pom_disable_module maven-%{name}-plugin-smoke
%mvn_package :*-{plugin} @1

# remove maven-compiler-plugin configuration that is broken with Java 11
%pom_xpath_remove 'pom:plugin[pom:artifactId="maven-compiler-plugin"]/pom:configuration'

# Disable default-jar execution of maven-jar-plugin, which is causing
# problems with version 3.0.0 of the plugin.
%pom_xpath_inject "pom:plugin[pom:artifactId='maven-jar-plugin']/pom:executions" "
    <execution>
      <id>default-jar</id>
      <phase>skip</phase>
    </execution>" cal10n-api

%build
%mvn_build -- -Dproject.build.sourceEncoding=ISO-8859-1 -Dmaven.compiler.source=1.8 -Dmaven.compiler.target=1.8

%install
%mvn_install

%files -f .mfiles
%dir %{_javadir}/%{name}
%license LICENSE.txt

%files -n maven-%{name}-plugin -f .mfiles-plugin

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt




%changelog
* Wed May 22 2024 ns80 <ns80> 0.8.1-8.mga10
+ Revision: 2066027
- rebuild for java 21

* Sat Mar 26 2022 umeabot <umeabot> 0.8.1-7.mga9
+ Revision: 1827603
- Mageia 9 Mass Rebuild

* Fri Sep 11 2020 daviddavid <daviddavid> 0.8.1-6.mga8
+ Revision: 1624395
- Repack the tarball without binaries
- Override javac source and target versions to fix build with Java 11
- Rebuilt for JDK-11

* Tue Feb 11 2020 umeabot <umeabot> 0.8.1-5.mga8
+ Revision: 1489301
- Mageia 8 Mass Rebuild

* Tue Sep 18 2018 umeabot <umeabot> 0.8.1-4.mga7
+ Revision: 1260354
- Mageia 7 Mass Rebuild

* Tue Sep 18 2018 umeabot <umeabot> 0.8.1-3.mga7
+ Revision: 1260105
- Mageia 7 Mass Rebuild

* Fri May 12 2017 neoclust <neoclust> 0.8.1-2.mga6
+ Revision: 1100579
- New version 0.8.1

* Wed Mar 02 2016 neoclust <neoclust> 0.7.7-8.mga6
+ Revision: 982098
- Second rebuild of the java stack

* Sun Feb 21 2016 neoclust <neoclust> 0.7.7-7.mga6
+ Revision: 975754
- First rebuild of the java stack
- sync package cal10n with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Sat Dec 27 2014 pterjan <pterjan> 0.7.7-6.mga5
+ Revision: 806506
- Add missing BuildRequires
- Sync with Fedora 21
- Restore
+ sander85 <sander85>
- Depends on broken java stack

* Wed Oct 15 2014 umeabot <umeabot> 0.7.7-4.mga5
+ Revision: 746888
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Wed Dec 18 2013 dmorgan <dmorgan> 0.7.7-2.mga4
+ Revision: 558492
- Fix BuildRequires
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Sun Sep 29 2013 dmorgan <dmorgan> 0.7.7-1.mga4
+ Revision: 489270
- New version

* Fri Jan 11 2013 umeabot <umeabot> 0.7.4-11.mga3
+ Revision: 347326
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Jan 04 2013 dmorgan <dmorgan> 0.7.4-10.mga3
+ Revision: 338785
- Simplify spec file ( remove ant build)

* Sun Jan 22 2012 gil <gil> 0.7.4-2.mga2
+ Revision: 199740
- build fix
  build with maven 3 support
  adapt to current guidelines
  new sub package maven-cal10n-smoke-plugin

* Thu Jan 20 2011 dmorgan <dmorgan> 0.7.4-1.mga1
+ Revision: 27288
- Ooooops i removed the wrong file
- Fix file list
- Fix docs
- Fix file list
- Fix jar file install
- Fix jar file name
- Fix hardcoded value
- Adapt to mageia
- Use OpenSource spec file for bootstraping
- imported package cal10n


* Thu Nov 25 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 0.7.4-4
- Fix pom filenames (Resolves rhbz#655792)
- Add several packages to Requires
- Remove versioned jars and javadocs

* Wed Sep 8 2010 Alexander Kurtakov <akurtako@redhat.com> 0.7.4-3
- Fix build failure (javadoc:aggregate).

* Mon Jul 19 2010 Alexander Kurtakov <akurtako@redhat.com> 0.7.4-2
- BR maven-site-plugin.

* Mon Jul 19 2010 Alexander Kurtakov <akurtako@redhat.com> 0.7.4-1
- Update to 0.7.4.

* Wed Feb 3 2010 Alexander Kurtakov <akurtako@redhat.com> 0.7.2-2
- Removed not needed external repo definitions.
- Use _mavenpomdir.

* Wed Feb 3 2010 Alexander Kurtakov <akurtako@redhat.com> 0.7.2-1
- Initial package
